# <span class="badge package-core"></span> dashboard

## Objects

 * <span class="badge object-type-class"></span> [AnnotationActions](./object-AnnotationActions.md)
 * <span class="badge object-type-class"></span> [AnnotationContainer](./object-AnnotationContainer.md)
 * <span class="badge object-type-class"></span> [AnnotationPanelFilter](./object-AnnotationPanelFilter.md)
 * <span class="badge object-type-class"></span> [AnnotationPermission](./object-AnnotationPermission.md)
 * <span class="badge object-type-class"></span> [AnnotationQuery](./object-AnnotationQuery.md)
 * <span class="badge object-type-class"></span> [AnnotationTarget](./object-AnnotationTarget.md)
 * <span class="badge object-type-class"></span> [Dashboard](./object-Dashboard.md)
 * <span class="badge object-type-enum"></span> [DashboardCursorSync](./object-DashboardCursorSync.md)
 * <span class="badge object-type-class"></span> [DashboardDashboardTemplating](./object-DashboardDashboardTemplating.md)
 * <span class="badge object-type-class"></span> [DashboardDashboardTime](./object-DashboardDashboardTime.md)
 * <span class="badge object-type-class"></span> [DashboardFieldConfigSourceOverrides](./object-DashboardFieldConfigSourceOverrides.md)
 * <span class="badge object-type-class"></span> [DashboardLink](./object-DashboardLink.md)
 * <span class="badge object-type-enum"></span> [DashboardLinkType](./object-DashboardLinkType.md)
 * <span class="badge object-type-class"></span> [DashboardMeta](./object-DashboardMeta.md)
 * <span class="badge object-type-class"></span> [DashboardRangeMapOptions](./object-DashboardRangeMapOptions.md)
 * <span class="badge object-type-class"></span> [DashboardRegexMapOptions](./object-DashboardRegexMapOptions.md)
 * <span class="badge object-type-class"></span> [DashboardSpecialValueMapOptions](./object-DashboardSpecialValueMapOptions.md)
 * <span class="badge object-type-class"></span> [DataSourceRef](./object-DataSourceRef.md)
 * <span class="badge object-type-class"></span> [DataTransformerConfig](./object-DataTransformerConfig.md)
 * <span class="badge object-type-class"></span> [DynamicConfigValue](./object-DynamicConfigValue.md)
 * <span class="badge object-type-class"></span> [FieldColor](./object-FieldColor.md)
 * <span class="badge object-type-enum"></span> [FieldColorModeId](./object-FieldColorModeId.md)
 * <span class="badge object-type-enum"></span> [FieldColorSeriesByMode](./object-FieldColorSeriesByMode.md)
 * <span class="badge object-type-class"></span> [FieldConfig](./object-FieldConfig.md)
 * <span class="badge object-type-class"></span> [FieldConfigSource](./object-FieldConfigSource.md)
 * <span class="badge object-type-class"></span> [GridPos](./object-GridPos.md)
 * <span class="badge object-type-class"></span> [LibraryPanelRef](./object-LibraryPanelRef.md)
 * <span class="badge object-type-enum"></span> [MappingType](./object-MappingType.md)
 * <span class="badge object-type-class"></span> [MatcherConfig](./object-MatcherConfig.md)
 * <span class="badge object-type-class"></span> [Panel](./object-Panel.md)
 * <span class="badge object-type-class"></span> [RangeMap](./object-RangeMap.md)
 * <span class="badge object-type-class"></span> [RegexMap](./object-RegexMap.md)
 * <span class="badge object-type-class"></span> [RowPanel](./object-RowPanel.md)
 * <span class="badge object-type-class"></span> [Snapshot](./object-Snapshot.md)
 * <span class="badge object-type-class"></span> [SpecialValueMap](./object-SpecialValueMap.md)
 * <span class="badge object-type-enum"></span> [SpecialValueMatch](./object-SpecialValueMatch.md)
 * <span class="badge object-type-class"></span> [Threshold](./object-Threshold.md)
 * <span class="badge object-type-class"></span> [ThresholdsConfig](./object-ThresholdsConfig.md)
 * <span class="badge object-type-enum"></span> [ThresholdsMode](./object-ThresholdsMode.md)
 * <span class="badge object-type-class"></span> [TimePickerConfig](./object-TimePickerConfig.md)
 * <span class="badge object-type-class"></span> [ValueMap](./object-ValueMap.md)
 * <span class="badge object-type-disjunction"></span> [ValueMapping](./object-ValueMapping.md)
 * <span class="badge object-type-class"></span> [ValueMappingResult](./object-ValueMappingResult.md)
 * <span class="badge object-type-enum"></span> [VariableHide](./object-VariableHide.md)
 * <span class="badge object-type-class"></span> [VariableModel](./object-VariableModel.md)
 * <span class="badge object-type-class"></span> [VariableOption](./object-VariableOption.md)
 * <span class="badge object-type-enum"></span> [VariableRefresh](./object-VariableRefresh.md)
 * <span class="badge object-type-enum"></span> [VariableSort](./object-VariableSort.md)
 * <span class="badge object-type-enum"></span> [VariableType](./object-VariableType.md)
## Builders

 * <span class="badge builder"></span> [AdHocVariable](./builder-AdHocVariable.md)
 * <span class="badge builder"></span> [AnnotationActions](./builder-AnnotationActions.md)
 * <span class="badge builder"></span> [AnnotationPanelFilter](./builder-AnnotationPanelFilter.md)
 * <span class="badge builder"></span> [AnnotationPermission](./builder-AnnotationPermission.md)
 * <span class="badge builder"></span> [AnnotationQuery](./builder-AnnotationQuery.md)
 * <span class="badge builder"></span> [AnnotationTarget](./builder-AnnotationTarget.md)
 * <span class="badge builder"></span> [ConstantVariable](./builder-ConstantVariable.md)
 * <span class="badge builder"></span> [CustomVariable](./builder-CustomVariable.md)
 * <span class="badge builder"></span> [Dashboard](./builder-Dashboard.md)
 * <span class="badge builder"></span> [DashboardDashboardTemplating](./builder-DashboardDashboardTemplating.md)
 * <span class="badge builder"></span> [DashboardFieldConfigSourceOverrides](./builder-DashboardFieldConfigSourceOverrides.md)
 * <span class="badge builder"></span> [DashboardLink](./builder-DashboardLink.md)
 * <span class="badge builder"></span> [DashboardMeta](./builder-DashboardMeta.md)
 * <span class="badge builder"></span> [DashboardRangeMapOptions](./builder-DashboardRangeMapOptions.md)
 * <span class="badge builder"></span> [DashboardRegexMapOptions](./builder-DashboardRegexMapOptions.md)
 * <span class="badge builder"></span> [DashboardSpecialValueMapOptions](./builder-DashboardSpecialValueMapOptions.md)
 * <span class="badge builder"></span> [DatasourceVariable](./builder-DatasourceVariable.md)
 * <span class="badge builder"></span> [FieldColor](./builder-FieldColor.md)
 * <span class="badge builder"></span> [IntervalVariable](./builder-IntervalVariable.md)
 * <span class="badge builder"></span> [Panel](./builder-Panel.md)
 * <span class="badge builder"></span> [QueryVariable](./builder-QueryVariable.md)
 * <span class="badge builder"></span> [Row](./builder-Row.md)
 * <span class="badge builder"></span> [Snapshot](./builder-Snapshot.md)
 * <span class="badge builder"></span> [TextBoxVariable](./builder-TextBoxVariable.md)
 * <span class="badge builder"></span> [ThresholdsConfig](./builder-ThresholdsConfig.md)
 * <span class="badge builder"></span> [TimePicker](./builder-TimePicker.md)
